==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.config.cascade.context/src/com/openexchange/config/cascade/context/matching/UserConfigurationAnalyzer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.config.cascade.context.matching;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import com.openexchange.groupware.userconfiguration.UserConfiguration;


/**
 * {@link UserConfigurationAnalyzer}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class UserConfigurationAnalyzer {

    // Time for a little reflection magic
    private static final Map<String, Method> getMethods = new HashMap<String, Method>();

    static {
        Method[] methods = UserConfiguration.class.getMethods();
        for (Method method : methods) {
            if (isCandidate(method)) {
                getMethods.put(getName(method), method);
            }
        }
    }


    public Set<String> getTags(UserConfiguration configuration) {
        Set<String> retval = new HashSet<String>();
        for(Map.Entry<String, Method> entry : getMethods.entrySet()) {
            String name = entry.getKey();
            Method m = entry.getValue();

            try {
                Boolean active = (Boolean) m.invoke(configuration);
                if(active) {
                    retval.add(name);
                }
            } catch (IllegalArgumentException e) {
                // Ignore
            } catch (IllegalAccessException e) {
                // Ignore
            } catch (InvocationTargetException e) {
                // Ignore
            }


        }
        return retval;
    }


    private static String getName(Method method) {
        String name = method.getName();
        StringBuilder nameBuilder = new StringBuilder("uc");
        boolean collect = false;
        for(char c : name.toCharArray()) {
            if (Character.isUpperCase(c)) {
                collect = true;
            }
            if(collect) {
                nameBuilder.append(c);
            }
        }
        return nameBuilder.toString();
    }


    private static boolean isCandidate(Method method) {
        Class<?> cls = method.getReturnType();
        boolean returnsBoolean = boolean.class.isAssignableFrom(cls) || Boolean.class.isAssignableFrom(cls);
        boolean hasNoParameters = method.getParameterTypes().length==0;
        return returnsBoolean && hasNoParameters;
    }
}

==> open-xchange-core_7.0.0.orig.tar.bz2: open-xchange-core-7.0.0/com.openexchange.config.cascade.context/src/com/openexchange/config/cascade/context/matching/UserConfigurationAnalyzer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.config.cascade.context.matching;

import java.util.HashSet;
import java.util.Set;

import com.openexchange.groupware.userconfiguration.UserConfiguration;
import com.openexchange.groupware.userconfiguration.UserConfiguration.Permission;


/**
 * {@link UserConfigurationAnalyzer}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class UserConfigurationAnalyzer {

	public Set<String> getTags(UserConfiguration configuration) {
        Set<String> retval = new HashSet<String>();

        int permissionBits = configuration.getPermissionBits();

        for (Permission p : Permission.values()) {
        	if ( (permissionBits & p.getBit()) == p.getBit()) {
        		retval.add("uc" + p.getTagName());
        	}
        }

        return retval;
    }

}
